@@ -1,4 +1,5 @@
 import json
+from jsonpath_ng import jsonpath, parse
 
 
 class Context:
@@ -31,7 +32,11 @@ class Message(Context):
 
     def get(self, key: str) -> object:
         msg = json.loads(self.data.decode('utf-8'))
-        return msg[key]
+        val = parse('$.%s' % key).find(msg)
+        if len(val) == 0:
+            return None
+
+        return val[0].value
 
     def get_raw(self) -> bytes:
         return self.data
